Module network_simplex

Module network_simplex 

Structs

NetworkSimplex
Authored by Leonhard Mühlmeyer (2024)

Enums

ArcDirection
Enum for representing the direction of an arc in the spanning tree
ArcState
Enum for representing the state of an arc in the spanning tree representation
ProblemType
Enum for representing the type of problem solved by the Network Simplex algorithm
SupplyType
Enum for representing the type of supply constraints in the network

Functions

select_max
Selects the maximum value from a slice of values. Compared to standard max() function, this only requires the PartialOrd trait.